Learn R Programming

compositions (version 0.9-11)

Read standard data files: Reads a data file in a geoeas format

Description

Reads a data file, which must be formatted either as a geoEAS file (described below).

Usage

read.geoeas(file)
read.geoEAS(file)

Arguments

file
a file name, with a specific format

Value

  • A data set, with a "title" attribute.

Details

The data files must be in the adequate format: "read.geoEAS" and "read.geoeas" read geoEAS format.

The geoEAS format has the following structure: itemize a first row with a description of the data set the number of variables (=nvars) "nvars" rows, each containing the name of a variable the data set, in a matrix of "nvars" columns and as many rows as individuals itemize

Labels and title should not contain tabs. This might produce an error when reading. [object Object] read.table

# # Files can be found in the test-subdirectory of the package # read.geoeas("TRUE.DAT") read.geoEAS("TRUE.DAT")