Learn R Programming

compositions (version 0.9-11)

ellipses: Draw ellipses

Description

Draws ellipses from a mean and a variance into a plot.

Usage

ellipses(mean,...)
          ## S3 method for class 'acomp':
ellipses(mean,var,r=1,\dots,steps=360)
          ## S3 method for class 'rcomp':
ellipses(mean,var,r=1,\dots,steps=360)
          ## S3 method for class 'aplus':
ellipses(mean,var,r=1,\dots,steps=360)
          ## S3 method for class 'rplus':
ellipses(mean,var,r=1,\dots,steps=360)
          ## S3 method for class 'rmult':
ellipses(mean,var,r=1,\dots,steps=360)

Arguments

mean
a dataset/value of means or midpoints of the ellipses
var
a variance matrix or a set of variance matrices given by var[i,,]. The principle axis of the variance give the axis of the ellipses. The the square-root of the eigenvalues times r give the large and small halfdiameter of the ellipse
r
A scaling of the radius
...
further graphical parameters
steps
the numer of discretisation points to draw the ellipses.

Details

The ellipse drawn is given by the solutions of $$(x-mean)^tvar^{-1}(x-mean)=r^2$$ in the respective geometry of the parameter space. Currently the compositional scales (acomp and rcomp) can be used only for three part compositions and plot into a ternary diagram and the not sum constrained scales (aplus, rplus and rmult) can only be used with two parts and draw into any scatterplot. TODO: Adding to multi-panel plots

See Also

plot.acomp,

Examples

Run this code
data(SimulatedAmounts)

plot(acomp(sa.lognormals))
tt<-acomp(sa.lognormals); ellipses(mean(tt),var(tt),r=2,col="red")
tt<-rcomp(sa.lognormals); ellipses(mean(tt),var(tt),r=2,col="blue")

plot(aplus(sa.lognormals[,1:2]))
tt<-aplus(sa.lognormals[,1:2]); ellipses(mean(tt),var(tt),r=2,col="red")
tt<-rplus(sa.lognormals[,1:2]); ellipses(mean(tt),var(tt),r=2,col="blue")

plot(rplus(sa.lognormals[,1:2]))
tt<-aplus(sa.lognormals[,1:2]); ellipses(mean(tt),var(tt),r=2,col="red")
tt<-rplus(sa.lognormals[,1:2]); ellipses(mean(tt),var(tt),r=2,col="blue")
tt<-rmult(sa.lognormals[,1:2]); ellipses(mean(tt),var(tt),r=2,col="green")

Run the code above in your browser using DataLab