Learn R Programming

compositions (version 0.9-11)

gsi.margin: Internal function: Compute a desired compositional margin

Description

This generic function should select the selected type of margin based on the class of the dataset and the specified margin type.

Usage

gsi.margin(X,...)
gsi.margin.acomp(X,what,...,margin="acomp")
gsi.margin.rcomp(X,what,...,margin="rcomp")
gsi.margin.aplus(X,what,...)
gsi.margin.rplus(X,what,...)

Arguments

X
The dataset to take the margin from.
what
The indices xor column names to be kept.
margin
The type of marginalisation to be used. Possible values are: '"sub"', '"rcomp"', '"acomp"' and an index xor a name of a variable in the dataset.
...
other arguments

Value

  • Some marginal dataset or vector still containing the variables given by what and optionally one additional part named '"+"', '"*"' or margin.

See Also

gsi

Examples

Run this code
data(SimulatedAmounts)
plot(gsi.margin(acomp(sa.lognormals5),c("Cd","Cu")))

Run the code above in your browser using DataLab