gsi.merge2signary( M )
gsi.ilrBase2signary( V )
gsi.optimalilrBase( x )
gsi.buildilrBase( W=c(1,-1) )
gsi.signary2ilrBase( W=c(1,-1) )
gsi.OrderIlr( V )hclust)ilrBase. Functions
gsi.merge2signary and gsi.ilrBase2signary return
a signary matrix (as explained in "details"), gsi.optimalilrBase
returns a merge structure (as epxlained in hclust), and
gsi.buildilrBase (and its alias gsi.signary2ilrBase)
returns an ilr matrix. These functions are thought to be called
sequentially.
Apart, gsi.OrderIlr reorders both parts and coordinates to
ease dendrogram-like representations (see CoDaDendrogram). Functions gsi.merge2signary and gsi.buildilrBase are
intended to compute ilrBase matrices associated to user-defined
partition structures. Function gsi.ilrBase2signary offers the
inverse functionality.
Function gsi.OrderIlr returns a list with two elements:
"ilrBase" and "order". The first one contains the ilr basis with
coordinates reordered in decreasing number of involved parts (so,
all parts are involved in the first coordinate, and only two in the
last). The second one gives a permutation of the parts so that
involved parts in each coordinate are always together.
Note that ilrBase does not have its parts permuted!
ilrBase,ipt,ilr,
m <- matrix(data=c(-1,-2,
-3,-4,
1, 2),ncol=2,nrow=3,byrow=TRUE)
w <- gsi.merge2signary(m)
w
V=gsi.buildilrBase(w)
V
gsi.ilrBase2signary(V)
gsi.OrderIlr(V)Run the code above in your browser using DataLab