Learn R Programming

compositions (version 0.9-11)

gsi.plain: Internal function: Convert to plain vector or matrix

Description

The dataset is converted into a plain vector or matrix: data.frames are converted to data matrices and class attributes are removed.

Usage

gsi.plain( x )

Arguments

x
The dataset to be converted

Value

  • unclassed object, typically a vector or matrix.

Examples

Run this code
gsi.plain(acomp(c(12,3,4)))

Run the code above in your browser using DataLab