Learn R Programming

compositions (version 0.9-11)

gsi.simshape: Internal function: Reshape an object to the shape type of another

Description

Reshape an object to the shape type of another

Usage

gsi.simshape(x,oldx)

Arguments

x
the data to be returned
oldx
a data of the intended shape

Value

  • x is shaped as oldx

Examples

Run this code
gsi.simshape(matrix(1:4,nrow=1),1:3)

Run the code above in your browser using DataLab