Learn R Programming

compositions (version 0.9-11)

gsiCoorInfo: Internal functions of the compositions package

Description

Sets or gets the current triangular coordinate system for the current ternary diagrams in the current plot.

Usage

gsi.getCoorInfo()
gsi.setCoorInfo(...)
gsi.plots

Arguments

...
The info to be set typically a mean=c(1,1,1) and scale=1

See Also

gsi,