Learn R Programming

compositions (version 0.9-11)

gsiinternal: Internal functions of the compositions package

Description

Internal function to compute 2D marginal compositions for plots

Usage

gsi.plotmargin(X,d,margin)

Arguments

X
A multivariate compositional dataset
d
a numeric or character vector of two elements specifying the margin
margin
a character specifying the type of margin to be choosen. Possible values are "acomp", "rcomp" or a column name from the dataset.

Value

  • a composition of three elements.

See Also

gsi