Compute the isometric planar transform of a (dataset of)
composition(s) and its inverse.
Usage
ipt( x , V = ilrBase(x) )
ipt.inv( z , V = ilrBase(z=z) )
ucipt.inv( z , V = ilrBase(z=z) )
Arguments
x
a composition or a data matrix of compositions, not necessarily closed
z
the ipt-transform of a composition or a data matrix of
ipt-transforms of compositions
V
a matrix with columns giving the chosen basis of the clr-plane
Value
ipt gives the centered planar transform,
ipt.inv gives closed compositions with with the given ipt-transforms,
ucipt.inv unconstrained ipt.inv does the same as ipt.inv but
sets illegal values to NA rather then giving an error. This is a
workaround to allow procedures not honoring the constraints of the
space.
Details
The ipt-transform maps a composition in the D-part real-simplex
isometrically to a D-1 dimensonal euclidian vector. Although the
transformation does not reach the whole $R^{D-1}$, resulting covariance
matrices are typically of full rank.
The data can then
be analysed in this transformation by all classical multivariate
analysis tools. However, interpretation of results may be
difficult, since the
transform does not keep the variable names, given that there is no
one-to-one relation between the original parts and each transformed variables. See
cpt and apt for alternatives.
The isometric planar transform is given by
$$ipt(x) := V^t cpt(x)$$
with cpt(x) the centred planar transform and
$V\in R^{d \times (d-1)}$ a matrix which columns form an orthonormal
basis of the clr-plane. A default matrix $V$ is given by
ilrBase(D)