Learn R Programming

compositions (version 0.9-11)

isoPortionLines: Isoportion- and Isoproportion-lines

Description

Add lines of equal portion and proportion to ternary diagrams.

Usage

isoPortionLines(...)
isoPortionLines.acomp(by=0.2,at=seq(0,1,by=by),...,parts=1:3,total=1,labs=TRUE,lines=TRUE,unit="")
isoPortionLines.rcomp(by=0.2,at=seq(0,1,by=by),...,parts=1:3,total=1,labs=TRUE,lines=TRUE,unit="")
isoProportionLines(...)
isoProportionLines.acomp(by=0.2,at=seq(0,1,by=by),...,parts=1:3,labs=TRUE,lines=TRUE) 
isoProportionLines.rcomp(by=0.2,at=seq(0,1,by=by),...,parts=1:3,labs=TRUE,lines=TRUE)

Arguments

...
graphical arguments
at
numeric in [0,1]: Which portions/proportions should be marked?
by
numeric in (0,1]:Steps between protions/proportions
parts
numeric vector subset of {1,2,3}: the variables to be marked
total
The total amount to be used in labeling
labs
logical: plot the labels?
lines
logical: plot the lines?
unit
marking the units e.g. "%"

Details

Isoportion lines give lines of the same portion of one of the parts, while isoproportion line gives lines of the same ratio between two parts. The isoproportion lines are Aitchison-lines in the simplex, while the isoportion-lines are, up to my knowledge, not.

See Also

plot.acomp

Examples

Run this code
data(SimulatedAmounts)
plot(acomp(sa.lognormals))
isoPortionLines()
plot(acomp(sa.lognormals),center=TRUE)
isoPortionLines()
plot(rcomp(sa.lognormals))
isoPortionLines()
plot(acomp(sa.lognormals))
isoProportionLines()
plot(acomp(sa.lognormals),center=TRUE)
isoProportionLines()
plot(rcomp(sa.lognormals))
isoProportionLines()

Run the code above in your browser using DataLab