Each of the considered space structures has an associated norm, which is
computed for each element by these functions.
Usage
norm(x,...)
## S3 method for class 'default':
norm(x,\dots)
## S3 method for class 'acomp':
norm(x,\dots)
## S3 method for class 'rcomp':
norm(x,\dots)
## S3 method for class 'aplus':
norm(x,\dots)
## S3 method for class 'rplus':
norm(x,\dots)
## S3 method for class 'rmult':
norm(x,\dots)
Arguments
x
a dataset or a single vector of some type
...
currently not used, intended to select a different norm