Computes a power of a positive semidefinite symmetric matrix.
Usage
powerofpsdmatrix( M , p,...)
Arguments
M
a Matrix, preferably symmetric
p
a single number giving the power
...
further arguments to the singular value decomposition
Value
U%*% D^p %*% t(P) where the UDP is a singular value
decomposition of M.
Details
for a symmetric matrix the computed result can actually be considered as
a version of the given power of the matrix fullfilling the relation:
$$M^pM^q=M^{p+q}$$
The symmetry of the matrix is not checked.