Learn R Programming

compositions (version 0.9-11)

rcompmargin: Marginal compositions in real geometry

Description

Compute marginal compositions by amalgamating the rest (additively).

Usage

rcompmargin(X,d=c(1,2),name="+",pos=length(d)+1)

Arguments

X
composition or dataset of compositions
d
vector containing the indices xor names of the columns to be kept
name
The new name of the amalgamation column
pos
The position where the new amalgamation column should be stored. This defaults to the last column.

Value

  • A closed compositions with class "rcomp" containing the selected variables given by d and the the amalgamation column.

Details

The amalgamation column is simply computed by adding the non-selected components after closing the composition. This is consistent with the rcomp approach and is widely used because of its easy interpretation. However, it often leads to difficult-to-read ternary diagrams and is inconsistent with the acomp approach.

See Also

acompmargin, rcomp

Examples

Run this code
data(SimulatedAmounts)
plot.rcomp(sa.tnormals5,margin="rcomp")
plot.rcomp(rcompmargin(sa.tnormals5,c("Cd","Zn")))
plot.rcomp(rcompmargin(sa.tnormals5,c(1,2)))

Run the code above in your browser using DataLab