vector or dataset of numbers considered as elements of a R-vector
parts
vector containing the indices xor names of the columns to be used
Value
a vector of class "rmult" representing one vector
or a matrix of class "rmult", representing
multiple vectors by rows.
Details
The rmult class is a simple convenience class to treat
data in the scale of real vectors just like data in the scale of real
numbers. A major aspect to take into account is that the internal arithmetic of R is
different for these vectors.