Learn R Programming

compositions (version 0.9-11)

ult: Uncentered log transform

Description

Compute the uncentered log ratio transform of a (dataset of) composition(s) and its inverse.

Usage

ult( x )
          ult.inv( z )
          Kappa( x )

Arguments

x
a composition or a data matrix of compositions, not necessarily closed
z
the ult-transform of a composition or a data matrix of clr-transforms of compositions, not necessarily centered

Value

  • ult gives the uncentered log transform, ult.inv gives closed compositions with the given ult-transforms Kappa gives the difference between the clr and the ult transform. It is quite linked to information measures.

Details

The ult-transform is simply the elementwise log of the closed composition. The ult has some important properties in the scope of Information Theory.

See Also

ilr,alr,apt

Examples

Run this code
(tmp <- ult(c(1,2,3)))
ult.inv(tmp)
ult.inv(tmp) - clo(c(1,2,3)) # 0
data(Hydrochem)
cdata <- Hydrochem[,6:19]
pairs(ult(cdata))
Kappa(c(1,2,3))

Run the code above in your browser using DataLab