The data files must be in the adequate format: "read.geoEAS" and
"read.geoeas" read geoEAS format. The geoEAS format has the following structure:
itemize
- a first row with a description of the data set
- the number of variables (=nvars)
- "nvars" rows, each containing the name of a variable
- the data set, in a matrix of "nvars" columns
and as many rows as individuals
itemize
Labels and title should not contain tabs.
This might produce an error when reading.
[object Object]
read.table
#
# Files can be found in the test-subdirectory of the package
#
read.geoeas("TRUE.DAT")
read.geoEAS("TRUE.DAT")