clo( X, parts=1:NCOL(oneOrDataset(X)),total=1,
detectionlimit=attr(X,"detectionlimit"),
BDL=NULL,MAR=NULL,MNAR=NULL,SZ=NULL,
storelimit=!is.null(attr(X,"detectionlimit"))
)gsi.getN(X) specifying a different total for each
compositional vector in the dataset.compositions.missing. The BDL values are
accordingly scaled during the scaling operations but not taken into
acount for the calculation of the total sum.clo generates a composition without assigning one of the
compositional classes acomp or rcomp.
Note that after computing the closed-to-one version, obtaining a
version closed to any other value is done by simple multiplication.clr,acomp,rcomp(tmp <- clo(c(1,2,3)))
clo(tmp,total=100)
data(Hydrochem)
plot( clo(Hydrochem,8:9) ) # Giving points on a lineRun the code above in your browser using DataLab