gsi.mapin01: Internal functions: Storing integers as reals
Description
An integer number is stored in a dataset with a given range.Usage
gsi.mapin01(i,min=0,max=1)
gsi.mapfrom01(x)
gsi.mapmin(x)
gsi.mapmax(x)
Value
gsi.mapin01 gives a vector x with
range(x)==c(min,max) and gsi.mapfrom01(x),
gsi.mapmin(x), gsi.mapmax(x) result in i,
max and min.
Details
The function is used to get full control over the graphic ranges in
pair plots and to pass the used column to panel functions.