pairs but allows to add additional panels
afterwardsgsi.pairs(x, labels, panel = points, ..., main = NULL, oma = NULL,
font.main = par("font.main"), cex.main = par("cex.main"),
lower.panel = panel, upper.panel = panel, diag.panel = NULL,
text.panel = textPanel, label.pos = 0.5 + has.diag/3, cex.labels = NULL,
font.labels = 1, row1attop = TRUE, gap = 1, add=list(),
xlim=apply(x,2,range), ylim=apply(x,2,range), log="",
onlyPanel=NULL,noplot=FALSE,trimode=FALSE)
gsi.add2pairs(x,panel,...,noplot=FALSE)
gsi.plotspairspairspairspairspairspairspairspairspairspairspairspairspairspairsncol(x)-matrix parameter giving in
xlim[,j] the xlims of the j-th columnncol(x)-matrix parameter giving in
ylim[,i] the ylims of the j-th columnplot allowing to log some plots, without a warninggsi.pairs essentially copies the functionality of
pairs. However it additionally stores its own
parameters in the dev.cur() position of gsi.plots and allows to modify
the parameters and re-do a modified plot afterwards. This is mainly
done by gsi.add2pairs by modifying the additional add
parameter, that specifies more panels. This mechanism should not be
used directly, since it is planed to replace it by a more rigorous solution soon.gsi,